yakumo.neutron.v2

Package yakumo :: Package neutron :: Package v2 |
[hide private]
[frames] | no frames]

# Source Code for Package yakumo.neutron.v2

     1  from . import floating_ip
     2  from . import lb
     3  from . import lbaas
     4  from . import network
     5  from . import port
     6  from . import quota
     7  from . import router
     8  from . import security_group
     9  from . import subnet
    10  from . import subnet_pool
    11  from . import vpn
    12  from . import metering
    13
    14
    15 -class Client(object):
    16
    17 -    def __init__(self, client, **kwargs):
    18          self.floating_ip = floating_ip.Manager(client, **kwargs)
    19          self.network = network.Manager(client, **kwargs)
    20          self.port = port.Manager(client, **kwargs)
    21          self.quota = quota.Manager(client, **kwargs)
    22          self.router = router.Manager(client, **kwargs)
    23          self.security_group = security_group.Manager(client, **kwargs)
    24          self.subnet = subnet.Manager(client, **kwargs)
    25          self.subnet_pool = subnet_pool.Manager(client, **kwargs)
    26          self.metering = metering.Client(client, **kwargs)
    27          self.lb = lb.Client(client, **kwargs)
    28          self.lbaas = lbaas.Client(client, **kwargs)
    29          self.vpn = vpn.Client(client, **kwargs)
    30
    31          client.floating_ip = self.floating_ip
    32          client.network = self.network
    33          client.port = self.port
    34          client.network_quota = self.quota
    35          client.router = self.router
    36          client.security_group = self.security_group
    37          client.subnet = self.subnet
    38          client.subnet_pool = self.subnet_pool
    39          client.lb = self.lb
    40          client.lbaas = self.lbaas
    41          client.vpn = self.vpn
    42